@@ -71,14 +71,20 @@ fi
 # xNVMe: where are libraries and share stored on the target system? This is
 # needed to find the xNVMe fio io-engine, fio scripts etc.
 #
-: "${XNVME_LIB_ROOT:=/usr/lib}"; export XNVME_LIB_ROOT
-: "${XNVME_SHARE_ROOT:=/usr/share/xnvme}"; export XNVME_SHARE_ROOT
+# Consult: 'pkg-config --variable="libdir" xnvme' on the target system
+: "${XNVME_LIB_ROOT:=/usr/local/lib/x86_64-linux-gnu}"; export XNVME_LIB_ROOT
+# Consult: 'pkg-config --variable="datadir" xnvme' on the target system
+: "${XNVME_SHARE_ROOT:=/usr/local/share/xnvme}"; export XNVME_SHARE_ROOT
 
 # These are for running fio
 if [[ -v NVME_NSTYPE ]]; then
   : "${SPDK_FIOE_ROOT:=/opt/aux}"; export SPDK_FIOE_ROOT
 fi
 
+# This is for the SPDK setup.sh script and xNVMe xnvme-driver script
+# It can be overwritten in the testplan
+HUGEMEM="${HUGEMEM:=2048}"; export HUGEMEM
+
 # The external fio io-engines usually depend on the fio-version on which they
 # built against. So, we set the FIO_BIN to point it to the version that comes
 # with the xNVMe dockerize reference environment
